var module_zeroconf_discover_8c =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "tunnel_info", "structtunnel__info.html", "structtunnel__info" ],
    [ "tunnel", "structtunnel.html", "structtunnel" ],
    [ "MODULE_USAGE", "module-zeroconf-discover_8c.html#acc847625d3fc806b4f854350e9c8a9d9", null ],
    [ "NAME", "module-zeroconf-discover_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "module-zeroconf-discover_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "SERVICE_TYPE_SINK", "module-zeroconf-discover_8c.html#a3c5e5e941964214873cc0278fe3d6c0b", null ],
    [ "SERVICE_TYPE_SOURCE", "module-zeroconf-discover_8c.html#a127ea30f7f804e0ed89ee4841fbac71b", null ],
    [ "TUNNEL_INFO", "module-zeroconf-discover_8c.html#adc7f07c5d99f6468e6dad4ffe9706a66", null ],
    [ "pipewire__module_init", "module-zeroconf-discover_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
    [ "PW_LOG_TOPIC_STATIC", "module-zeroconf-discover_8c.html#aa0d958627aeb2fb6f2e897d656b5c0c6", null ]
];